Application class

Describes an application in the application catalog.

Constructors

Application({String? displayName, bool? enabled, String? iconURL, String? launchParameters, String? launchPath, Map<String, String>? metadata, String? name})
Application.fromJson(Map<String, dynamic> json)
factory

Properties

displayName → String?
The application name to display.
final
enabled → bool?
If there is a problem, the application can be disabled after image creation.
final
hashCode → int
The hash code for this object.
no setterinherited
iconURL → String?
The URL for the application icon. This URL might be time-limited.
final
launchParameters → String?
The arguments that are passed to the application at launch.
final
launchPath → String?
The path to the application executable in the instance.
final
metadata → Map<String, String>?
Additional attributes that describe the application.
final
name → String?
The name of the application.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited