ComputeCapacityStatus class

Describes the capacity status for a fleet.

Constructors

ComputeCapacityStatus({required int desired, int? available, int? inUse, int? running})
ComputeCapacityStatus.fromJson(Map<String, dynamic> json)
factory

Properties

available → int?
The number of currently available instances that can be used to stream sessions.
final
desired → int
The desired number of streaming instances.
final
hashCode → int
The hash code for this object.
no setterinherited
inUse → int?
The number of instances in use for streaming.
final
running → int?
The total number of simultaneous streaming instances that are running.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited