CreateUsageReportSubscriptionResult class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3BucketName → String?
The Amazon S3 bucket where generated reports are stored.
final
schedule → UsageReportSchedule?
The schedule for generating usage reports.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited