DescribeUsersResult class

Constructors

DescribeUsersResult({String? nextToken, List<User>? users})
DescribeUsersResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
users → List<User>?
Information about users in the user pool.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited