DirectoryConfig class

Describes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.

Constructors

DirectoryConfig({required String directoryName, DateTime? createdTime, List<String>? organizationalUnitDistinguishedNames, ServiceAccountCredentials? serviceAccountCredentials})
DirectoryConfig.fromJson(Map<String, dynamic> json)
factory

Properties

createdTime → DateTime?
The time the directory configuration was created.
final
directoryName → String
The fully qualified name of the directory (for example, corp.example.com).
final
hashCode → int
The hash code for this object.
no setterinherited
organizationalUnitDistinguishedNames → List<String>?
The distinguished names of the organizational units for computer accounts.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountCredentials → ServiceAccountCredentials?
The credentials for the service account used by the fleet or image builder to connect to the directory.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited