DomainJoinInfo class

Describes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.

Constructors

DomainJoinInfo({String? directoryName, String? organizationalUnitDistinguishedName})
DomainJoinInfo.fromJson(Map<String, dynamic> json)
factory

Properties

directoryName → String?
The fully qualified name of the directory (for example, corp.example.com).
final
hashCode → int
The hash code for this object.
no setterinherited
organizationalUnitDistinguishedName → String?
The distinguished name of the organizational unit for computer accounts.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited