Image class

Describes an image.

Constructors

Image({required String name, List<Application>? applications, String? appstreamAgentVersion, String? arn, String? baseImageArn, DateTime? createdTime, String? description, String? displayName, String? imageBuilderName, bool? imageBuilderSupported, ImagePermissions? imagePermissions, PlatformType? platform, DateTime? publicBaseImageReleasedDate, ImageState? state, ImageStateChangeReason? stateChangeReason, VisibilityType? visibility})
Image.fromJson(Map<String, dynamic> json)
factory

Properties

applications → List<Application>?
The applications associated with the image.
final
appstreamAgentVersion → String?
The version of the AppStream 2.0 agent to use for instances that are launched from this image.
final
arn → String?
The ARN of the image.
final
baseImageArn → String?
The ARN of the image from which this image was created.
final
createdTime → DateTime?
The time the image was created.
final
description → String?
The description to display.
final
displayName → String?
The image name to display.
final
hashCode → int
The hash code for this object.
no setterinherited
imageBuilderName → String?
The name of the image builder that was used to create the private image. If the image is shared, this value is null.
final
imageBuilderSupported → bool?
Indicates whether an image builder can be launched from this image.
final
imagePermissions → ImagePermissions?
The permissions to provide to the destination AWS account for the specified image.
final
name → String
The name of the image.
final
platform → PlatformType?
The operating system platform of the image.
final
publicBaseImageReleasedDate → DateTime?
The release date of the public base image. For private images, this date is the release date of the base image from which the image was created.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ImageState?
The image starts in the PENDING state. If image creation succeeds, the state is AVAILABLE. If image creation fails, the state is FAILED.
final
stateChangeReason → ImageStateChangeReason?
The reason why the last state change occurred.
final
visibility → VisibilityType?
Indicates whether the image is public or private.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited