ImageBuilder class

Describes a virtual machine that is used to create an image.

Constructors

ImageBuilder({required String name, List<AccessEndpoint>? accessEndpoints, String? appstreamAgentVersion, String? arn, DateTime? createdTime, String? description, String? displayName, DomainJoinInfo? domainJoinInfo, bool? enableDefaultInternetAccess, String? iamRoleArn, String? imageArn, List<ResourceError>? imageBuilderErrors, String? instanceType, NetworkAccessConfiguration? networkAccessConfiguration, PlatformType? platform, ImageBuilderState? state, ImageBuilderStateChangeReason? stateChangeReason, VpcConfig? vpcConfig})
ImageBuilder.fromJson(Map<String, dynamic> json)
factory

Properties

accessEndpoints → List<AccessEndpoint>?
The list of virtual private cloud (VPC) interface endpoint objects. Administrators can connect to the image builder only through the specified endpoints.
final
appstreamAgentVersion → String?
The version of the AppStream 2.0 agent that is currently being used by the image builder.
final
arn → String?
The ARN for the image builder.
final
createdTime → DateTime?
The time stamp when the image builder was created.
final
description → String?
The description to display.
final
displayName → String?
The image builder name to display.
final
domainJoinInfo → DomainJoinInfo?
The name of the directory and organizational unit (OU) to use to join the image builder to a Microsoft Active Directory domain.
final
enableDefaultInternetAccess → bool?
Enables or disables default internet access for the image builder.
final
hashCode → int
The hash code for this object.
no setterinherited
iamRoleArn → String?
The ARN of the IAM role that is applied to the image builder. To assume a role, the image builder calls the AWS Security Token Service (STS) AssumeRole API operation and passes the ARN of the role to use. The operation creates a new session with temporary credentials. AppStream 2.0 retrieves the temporary credentials and creates the appstream_machine_role credential profile on the instance.
final
imageArn → String?
The ARN of the image from which this builder was created.
final
imageBuilderErrors → List<ResourceError>?
The image builder errors.
final
instanceType → String?
The instance type for the image builder. The following instance types are available:
final
name → String
The name of the image builder.
final
networkAccessConfiguration → NetworkAccessConfiguration?
final
platform → PlatformType?
The operating system platform of the image builder.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ImageBuilderState?
The state of the image builder.
final
stateChangeReason → ImageBuilderStateChangeReason?
The reason why the last state change occurred.
final
vpcConfig → VpcConfig?
The VPC configuration of the image builder.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited