ImagePermissions class

Describes the permissions for an image.

Constructors

ImagePermissions({bool? allowFleet, bool? allowImageBuilder})
ImagePermissions.fromJson(Map<String, dynamic> json)
factory

Properties

allowFleet → bool?
Indicates whether the image can be used for a fleet.
final
allowImageBuilder → bool?
Indicates whether the image can be used for an image builder.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited