LastReportGenerationExecutionError class

Describes the error that is returned when a usage report can't be generated.

Properties

errorCode → UsageReportExecutionErrorCode?
The error code for the error that is returned when a usage report can't be generated.
final
errorMessage → String?
The error message for the error that is returned when a usage report can't be generated.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited