NetworkAccessConfiguration class

Describes the network details of the fleet or image builder instance.

Constructors

NetworkAccessConfiguration({String? eniId, String? eniPrivateIpAddress})
NetworkAccessConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

eniId → String?
The resource identifier of the elastic network interface that is attached to instances in your VPC. All network interfaces have the eni-xxxxxxxx resource identifier.
final
eniPrivateIpAddress → String?
The private IP address of the elastic network interface that is attached to instances in your VPC.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited