ResourceError class

Describes a resource error.

Constructors

ResourceError({FleetErrorCode? errorCode, String? errorMessage, DateTime? errorTimestamp})
ResourceError.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → FleetErrorCode?
The error code.
final
errorMessage → String?
The error message.
final
errorTimestamp → DateTime?
The time the error occurred.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited