ServiceAccountCredentials class

Describes the credentials for the service account used by the fleet or image builder to connect to the directory.

Constructors

ServiceAccountCredentials({required String accountName, required String accountPassword})
ServiceAccountCredentials.fromJson(Map<String, dynamic> json)
factory

Properties

accountName → String
The user name of the account. This account must have the following privileges: create computer objects, join computers to the domain, and change/reset the password on descendant computer objects for the organizational units specified.
final
accountPassword → String
The password for the account.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited