Stack class

Describes a stack.

Constructors

Stack({required String name, List<AccessEndpoint>? accessEndpoints, ApplicationSettingsResponse? applicationSettings, String? arn, DateTime? createdTime, String? description, String? displayName, List<String>? embedHostDomains, String? feedbackURL, String? redirectURL, List<StackError>? stackErrors, List<StorageConnector>? storageConnectors, List<UserSetting>? userSettings})
Stack.fromJson(Map<String, dynamic> json)
factory

Properties

accessEndpoints → List<AccessEndpoint>?
The list of virtual private cloud (VPC) interface endpoint objects. Users of the stack can connect to AppStream 2.0 only through the specified endpoints.
final
applicationSettings → ApplicationSettingsResponse?
The persistent application settings for users of the stack.
final
arn → String?
The ARN of the stack.
final
createdTime → DateTime?
The time the stack was created.
final
description → String?
The description to display.
final
displayName → String?
The stack name to display.
final
embedHostDomains → List<String>?
The domains where AppStream 2.0 streaming sessions can be embedded in an iframe. You must approve the domains that you want to host embedded AppStream 2.0 streaming sessions.
final
feedbackURL → String?
The URL that users are redirected to after they click the Send Feedback link. If no URL is specified, no Send Feedback link is displayed.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the stack.
final
redirectURL → String?
The URL that users are redirected to after their streaming session ends.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackErrors → List<StackError>?
The errors for the stack.
final
storageConnectors → List<StorageConnector>?
The storage connectors to enable.
final
userSettings → List<UserSetting>?
The actions that are enabled or disabled for users during their streaming sessions. By default these actions are enabled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited