StackError class

Describes a stack error.

Constructors

StackError({StackErrorCode? errorCode, String? errorMessage})
StackError.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → StackErrorCode?
The error code.
final
errorMessage → String?
The error message.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited