UsageReportSubscription class

Describes information about the usage report subscription.

Constructors

UsageReportSubscription({DateTime? lastGeneratedReportDate, String? s3BucketName, UsageReportSchedule? schedule, List<LastReportGenerationExecutionError>? subscriptionErrors})
UsageReportSubscription.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastGeneratedReportDate → DateTime?
The time when the last usage report was generated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3BucketName → String?
The Amazon S3 bucket where generated reports are stored.
final
schedule → UsageReportSchedule?
The schedule for generating usage reports.
final
subscriptionErrors → List<LastReportGenerationExecutionError>?
The errors that were returned if usage reports couldn't be generated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited