User class

Describes a user in the user pool.

Constructors

User({required AuthenticationType authenticationType, String? arn, DateTime? createdTime, bool? enabled, String? firstName, String? lastName, String? status, String? userName})
User.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN of the user.
final
authenticationType → AuthenticationType
The authentication type for the user.
final
createdTime → DateTime?
The date and time the user was created in the user pool.
final
enabled → bool?
Specifies whether the user in the user pool is enabled.
final
firstName → String?
The first name, or given name, of the user.
final
hashCode → int
The hash code for this object.
no setterinherited
lastName → String?
The last name, or surname, of the user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The status of the user in the user pool. The status can be one of the following:
final
userName → String?
The email address of the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited