UserSetting class

Describes an action and whether the action is enabled or disabled for users during their streaming sessions.

Constructors

UserSetting({required Action action, required Permission permission})
UserSetting.fromJson(Map<String, dynamic> json)
factory

Properties

action → Action
The action that is enabled or disabled.
final
hashCode → int
The hash code for this object.
no setterinherited
permission → Permission
Indicates whether the action is enabled or disabled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited