UserStackAssociation class

Describes a user in the user pool and the associated stack.

Constructors

UserStackAssociation({required AuthenticationType authenticationType, required String stackName, required String userName, bool? sendEmailNotification})
UserStackAssociation.fromJson(Map<String, dynamic> json)
factory

Properties

authenticationType → AuthenticationType
The authentication type for the user.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendEmailNotification → bool?
Specifies whether a welcome email is sent to a user after the user is created in the user pool.
final
stackName → String
The name of the stack that is associated with the user.
final
userName → String
The email address of the user who is associated with the stack.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited