UserStackAssociationError class

Describes the error that is returned when a user can’t be associated with or disassociated from a stack.

Constructors

UserStackAssociationError({UserStackAssociationErrorCode? errorCode, String? errorMessage, UserStackAssociation? userStackAssociation})
UserStackAssociationError.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → UserStackAssociationErrorCode?
The error code for the error that is returned when a user can’t be associated with or disassociated from a stack.
final
errorMessage → String?
The error message for the error that is returned when a user can’t be associated with or disassociated from a stack.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userStackAssociation → UserStackAssociation?
Information about the user and associated stack.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited